#!/bin/bash
cd "$(dirname "${BASH_SOURCE[0]}")"

# Check AVX2 support
cputype=generic
if grep -Fqi avx2 /proc/cpuinfo; then
	echo "Detected AVX2 support"
	cputype=avx2
fi

function install_vlc()
{
	echo "************************"
	echo "Installing VLC plugin..."
	echo "************************"
	
	# Check arch
	arch=`uname -m`
	if [[ $arch == i?86 ]] ; then
		arch=x86
	elif [[ $arch == x86_64 ]] ; then
		arch=x64
	else
		echo >&2 "Unsupported architecture: '$arch'. Skipping."
		return 1
	fi
	
	# Check for vlc
	command -v vlc >/dev/null 2>&1 || { echo >&2 "VLC doesn't seem to be installed.  Skipping."; return 1; }
	vlcbin=`command -v vlc`
	
	# Try to determine VLC version
	regex="([[:digit:]])+\.([[:digit:]])+\.([[:digit:]])+"
	vlcout=`$vlcbin --version 2>/dev/null`
	[[ $vlcout =~ $regex ]]
	maj="${BASH_REMATCH[1]}"
	min="${BASH_REMATCH[2]}"
	rev="${BASH_REMATCH[3]}"
	echo "Detected VLC: $vlcbin ($arch) $maj.$min.$rev"
	
	# Check if we have a matching plugin
	plugin="$(pwd)/VLC/$arch/$cputype/$maj.$min.x/libmagicyuv_plugin.so"
	if [ ! -f "$plugin" ] ; then
		echo >&2 "There is no MagicYUV codec available for this VLC version. Skipping."
		return 1
	fi
	
	# Check VLC plugins dir
	vlccodecs=$(readlink -m $(dirname $vlcbin)/../lib/vlc/plugins/codec)
	if [ ! -d "$vlccodecs" ]; then
		echo >&2 "Assumed VLC codecs dir '$vlccodecs' doesn't exist. Skipping."
		return 1
	fi
	
	# Install
	echo "Installing '$plugin' to '$vlccodecs'"
	sudo cp -v $plugin $vlccodecs || { echo >&2 "Plugin installation failed."; return 1; }
	echo "Done."
}	

install_vlc
echo ""
